exit_perror

Function exit_perror 

pub fn exit_perror<E: Display>(msg: &str, err: E) -> !
👎Deprecated: This module is in maintenance mode; the anyhow library might be a better choice
Display the specified message and append an appropriate description of the error, then unwind the stack and exit.